@@ -39,7 +39,7 @@ eel_accessibility_set_up_label_widget_relation (GtkWidget *label, GtkWidget *wid
 	atk_object_add_relationship (atk_label, ATK_RELATION_LABEL_FOR, atk_widget);
 
 	/* Create the widget -> label relation */
-	atk_object_add_relationship (atk_label, ATK_RELATION_LABELLED_BY, atk_widget);
+	atk_object_add_relationship (atk_widget, ATK_RELATION_LABELLED_BY, atk_label);
 }
 
 /*
@@ -356,7 +356,7 @@ eel_accessibility_simple_text_interface_init (AtkTextIface *iface)
 void
 eel_accessibility_add_simple_text (GType type)
 {
-	static const GInterfaceInfo simple_text_info = {
+	const GInterfaceInfo simple_text_info = {
 		(GInterfaceInitFunc)
 		eel_accessibility_simple_text_interface_init,
 		(GInterfaceFinalizeFunc) NULL,
@@ -375,7 +375,7 @@ eel_accessible_text_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		static const GTypeInfo tinfo = {
+		const GTypeInfo tinfo = {
 			sizeof (AtkTextIface),
 			(GBaseInitFunc) NULL,
 			(GBaseFinalizeFunc) NULL,
