@@ -34,11 +34,11 @@
 static GdkPixbuf *
 create_new_pixbuf (GdkPixbuf *src)
 {
-	g_return_val_if_fail (gdk_pixbuf_get_colorspace (src) == GDK_COLORSPACE_RGB, NULL);
-	g_return_val_if_fail ((!gdk_pixbuf_get_has_alpha (src)
+	g_assert (gdk_pixbuf_get_colorspace (src) == GDK_COLORSPACE_RGB);
+	g_assert ((!gdk_pixbuf_get_has_alpha (src)
 			       && gdk_pixbuf_get_n_channels (src) == 3)
 			      || (gdk_pixbuf_get_has_alpha (src)
-				  && gdk_pixbuf_get_n_channels (src) == 4), NULL);
+				  && gdk_pixbuf_get_n_channels (src) == 4));
 
 	return gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src),
 			       gdk_pixbuf_get_has_alpha (src),
@@ -50,11 +50,11 @@ create_new_pixbuf (GdkPixbuf *src)
 static GdkPixbuf *
 create_new_pixbuf_with_alpha (GdkPixbuf *src)
 {
-	g_return_val_if_fail (gdk_pixbuf_get_colorspace (src) == GDK_COLORSPACE_RGB, NULL);
-	g_return_val_if_fail ((!gdk_pixbuf_get_has_alpha (src)
+	g_assert (gdk_pixbuf_get_colorspace (src) == GDK_COLORSPACE_RGB);
+	g_assert ((!gdk_pixbuf_get_has_alpha (src)
 			       && gdk_pixbuf_get_n_channels (src) == 3)
 			      || (gdk_pixbuf_get_has_alpha (src)
-				  && gdk_pixbuf_get_n_channels (src) == 4), NULL);
+				  && gdk_pixbuf_get_n_channels (src) == 4));
 
 	return gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src),
 			       TRUE,
