@@ -95,15 +95,11 @@ static GtkType       eel_wrap_table_child_type           (GtkContainer        *c
 
 
 /* Private EelWrapTable methods */
-static EelDimensions wrap_table_art_irect_max_dimensions (const EelDimensions *one,
+static EelDimensions wrap_table_irect_max_dimensions     (const EelDimensions *one,
 							  const EelDimensions *two);
 static EelDimensions wrap_table_get_max_child_dimensions (const EelWrapTable  *wrap_table);
 static EelDimensions wrap_table_get_content_dimensions   (const EelWrapTable  *wrap_table);
-static ArtIRect      wrap_table_get_content_bounds       (const EelWrapTable  *wrap_table);
-static EelArtIPoint  wrap_table_get_scroll_offset        (const EelWrapTable  *wrap_table);
-static GtkWidget *   wrap_table_find_child_at_point      (const EelWrapTable  *wrap_table,
-							  int                  x,
-							  int                  y);
+static EelIRect      wrap_table_get_content_bounds       (const EelWrapTable  *wrap_table);
 static gboolean      wrap_table_child_focus_in           (GtkWidget           *widget,
 							  GdkEventFocus       *event,
 							  gpointer             data);
@@ -212,7 +208,7 @@ eel_wrap_table_set_property (GObject      *object,
 {
 	EelWrapTable *wrap_table;
 	
-	g_return_if_fail (EEL_IS_WRAP_TABLE (object));
+	g_assert (EEL_IS_WRAP_TABLE (object));
 
  	wrap_table = EEL_WRAP_TABLE (object);
 
@@ -251,7 +247,7 @@ eel_wrap_table_get_property (GObject    *object,
 {
 	EelWrapTable *wrap_table;
 
-	g_return_if_fail (EEL_IS_WRAP_TABLE (object));
+	g_assert (EEL_IS_WRAP_TABLE (object));
 	
 	wrap_table = EEL_WRAP_TABLE (object);
 
@@ -290,8 +286,8 @@ eel_wrap_table_size_request (GtkWidget *widget,
 	EelWrapTable *wrap_table;
 	EelDimensions content_dimensions;
 
- 	g_return_if_fail (EEL_IS_WRAP_TABLE (widget));
- 	g_return_if_fail (requisition != NULL);
+ 	g_assert (EEL_IS_WRAP_TABLE (widget));
+ 	g_assert (requisition != NULL);
 
   	wrap_table = EEL_WRAP_TABLE (widget);
 
@@ -308,8 +304,8 @@ eel_wrap_table_size_allocate (GtkWidget *widget,
 {
 	EelWrapTable *wrap_table;
 
- 	g_return_if_fail (EEL_IS_WRAP_TABLE (widget));
- 	g_return_if_fail (allocation != NULL);
+ 	g_assert (EEL_IS_WRAP_TABLE (widget));
+ 	g_assert (allocation != NULL);
 	
   	wrap_table = EEL_WRAP_TABLE (widget);
 	
@@ -325,9 +321,9 @@ eel_wrap_table_expose_event (GtkWidget *widget,
 	EelWrapTable *wrap_table;
 	GList *iterator;
 	
-	g_return_val_if_fail (EEL_IS_WRAP_TABLE (widget), TRUE);
-	g_return_val_if_fail (GTK_WIDGET_REALIZED (widget), TRUE);
-	g_return_val_if_fail (event != NULL, TRUE);
+	g_assert (EEL_IS_WRAP_TABLE (widget));
+	g_assert (GTK_WIDGET_REALIZED (widget));
+	g_assert (event != NULL);
 
   	wrap_table = EEL_WRAP_TABLE (widget);
 
@@ -347,7 +343,7 @@ eel_wrap_table_map (GtkWidget *widget)
 	EelWrapTable *wrap_table;
 	GList *iterator;
 
-	g_return_if_fail (EEL_IS_WRAP_TABLE (widget));
+	g_assert (EEL_IS_WRAP_TABLE (widget));
 	
 	wrap_table = EEL_WRAP_TABLE (widget);
 
@@ -370,7 +366,7 @@ eel_wrap_table_unmap (GtkWidget *widget)
 	EelWrapTable *wrap_table;
 	GList *iterator;
 
-	g_return_if_fail (EEL_IS_WRAP_TABLE (widget));
+	g_assert (EEL_IS_WRAP_TABLE (widget));
 	
 	wrap_table = EEL_WRAP_TABLE (widget);
 
@@ -390,7 +386,7 @@ eel_wrap_table_unmap (GtkWidget *widget)
 static void
 eel_wrap_table_realize (GtkWidget *widget)
 {
-	g_return_if_fail (EEL_IS_WRAP_TABLE (widget));
+	g_assert (EEL_IS_WRAP_TABLE (widget));
 
 	GTK_WIDGET_CLASS (parent_class)->realize (widget);
 
@@ -404,9 +400,9 @@ eel_wrap_table_add (GtkContainer *container,
 {
 	EelWrapTable *wrap_table;
 
-	g_return_if_fail (container != NULL);
-	g_return_if_fail (EEL_IS_WRAP_TABLE (container));
-	g_return_if_fail (GTK_IS_WIDGET (child));
+	g_assert (container != NULL);
+	g_assert (EEL_IS_WRAP_TABLE (container));
+	g_assert (GTK_IS_WIDGET (child));
 
 	wrap_table = EEL_WRAP_TABLE (container);
 
@@ -440,8 +436,8 @@ eel_wrap_table_remove (GtkContainer *container,
 	EelWrapTable *wrap_table;
 	gboolean child_was_visible;
 	
-	g_return_if_fail (EEL_IS_WRAP_TABLE (container));
-	g_return_if_fail (GTK_IS_WIDGET (child));
+	g_assert (EEL_IS_WRAP_TABLE (container));
+	g_assert (GTK_IS_WIDGET (child));
 	
 	wrap_table = EEL_WRAP_TABLE (container);;
 
@@ -471,8 +467,8 @@ eel_wrap_table_forall (GtkContainer *container,
 	GList *node;
 	GList *next;
 	
-	g_return_if_fail (EEL_IS_WRAP_TABLE (container));
-	g_return_if_fail (callback != NULL);
+	g_assert (EEL_IS_WRAP_TABLE (container));
+	g_assert (callback != NULL);
 	
 	wrap_table = EEL_WRAP_TABLE (container);;
 	
@@ -497,8 +493,8 @@ wrap_table_get_num_fitting (int available,
 {
 	int num;
 
-  	g_return_val_if_fail (max_child_size > 0, 0);
-  	g_return_val_if_fail (spacing >= 0, 0);
+  	g_assert (max_child_size > 0);
+  	g_assert (spacing >= 0);
 
 	available = MAX (available, 0);
 	
@@ -512,12 +508,12 @@ static void
 wrap_table_layout (EelWrapTable *wrap_table)
 {
 	GList *iterator;
-	EelArtIPoint pos;
+	EelIPoint pos;
 	EelDimensions max_child_dimensions;
-	ArtIRect content_bounds;
+	EelIRect content_bounds;
 	guint num_cols;
 
- 	g_return_if_fail (EEL_IS_WRAP_TABLE (wrap_table));
+ 	g_assert (EEL_IS_WRAP_TABLE (wrap_table));
 
 	max_child_dimensions = wrap_table_get_max_child_dimensions (wrap_table);
 	content_bounds = wrap_table_get_content_bounds (wrap_table);
@@ -607,13 +603,13 @@ wrap_table_layout (EelWrapTable *wrap_table)
 }
 
 static EelDimensions
-wrap_table_art_irect_max_dimensions (const EelDimensions *one,
+wrap_table_irect_max_dimensions (const EelDimensions *one,
 				     const EelDimensions *two)
 {
 	EelDimensions max_dimensions;
 
-	g_return_val_if_fail (one != NULL, eel_dimensions_empty);
-	g_return_val_if_fail (two != NULL, eel_dimensions_empty);
+	g_assert (one != NULL);
+	g_assert (two != NULL);
 
 	max_dimensions.width = MAX (one->width, two->width);
 	max_dimensions.height = MAX (one->height, two->height);
@@ -627,7 +623,7 @@ wrap_table_get_max_child_dimensions (const EelWrapTable *wrap_table)
 	EelDimensions max_dimensions;
 	GList *iterator;
 
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), eel_dimensions_empty);
+  	g_assert (EEL_IS_WRAP_TABLE (wrap_table));
 
 	max_dimensions = eel_dimensions_empty;
 
@@ -645,7 +641,7 @@ wrap_table_get_max_child_dimensions (const EelWrapTable *wrap_table)
 			child_dimensions.width = (int) child_requisition.width;
 			child_dimensions.height = (int) child_requisition.height;
 
-			max_dimensions = wrap_table_art_irect_max_dimensions (&child_dimensions, &max_dimensions);
+			max_dimensions = wrap_table_irect_max_dimensions (&child_dimensions, &max_dimensions);
 		}
 	}
 
@@ -658,7 +654,7 @@ wrap_table_get_content_dimensions (const EelWrapTable *wrap_table)
 	EelDimensions content_dimensions;
 	guint num_children;
 
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), eel_dimensions_empty);
+  	g_assert (EEL_IS_WRAP_TABLE (wrap_table));
 
 	content_dimensions = eel_dimensions_empty;
 	
@@ -697,12 +693,12 @@ wrap_table_get_content_dimensions (const EelWrapTable *wrap_table)
 	return content_dimensions;
 }
 
-static ArtIRect
+static EelIRect
 wrap_table_get_content_bounds (const EelWrapTable *wrap_table)
 {
-	ArtIRect content_bounds;
+	EelIRect content_bounds;
 
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), eel_art_irect_empty);
+  	g_assert (EEL_IS_WRAP_TABLE (wrap_table));
 
 	content_bounds = eel_gtk_widget_get_bounds (GTK_WIDGET (wrap_table));
 
@@ -714,37 +710,13 @@ wrap_table_get_content_bounds (const EelWrapTable *wrap_table)
 	return content_bounds;
 }
 
-static EelArtIPoint
-wrap_table_get_scroll_offset (const EelWrapTable *wrap_table)
-{
-	EelArtIPoint scroll_offset;
-	GtkWidget *parent;
-
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), eel_art_ipoint_zero);
-
-	scroll_offset = eel_art_ipoint_zero;
-
-	parent = GTK_WIDGET (wrap_table)->parent;
-
-	/* FIXME: It lame we have to hardcode for a possible viewport 
-	 * parent here.  Theres probably a better way to do this
-	 */
-	if (GTK_IS_VIEWPORT (parent)) {
-		gdk_window_get_position (GTK_VIEWPORT (parent)->bin_window,
-					 &scroll_offset.x,
-					 &scroll_offset.y);
-	}
-
-	return scroll_offset;
-}
-
 static gboolean
 wrap_table_child_focus_in (GtkWidget *widget, 
 			   GdkEventFocus *event, 
 			   gpointer data)
 {
-	g_return_val_if_fail (widget->parent && widget->parent->parent, FALSE);
-	g_return_val_if_fail (GTK_IS_VIEWPORT (widget->parent->parent), FALSE);
+	g_assert (widget->parent && widget->parent->parent);
+	g_assert (GTK_IS_VIEWPORT (widget->parent->parent));
 
 	eel_gtk_viewport_scroll_to_rect (GTK_VIEWPORT (widget->parent->parent), 
 					 &widget->allocation);
@@ -752,34 +724,6 @@ wrap_table_child_focus_in (GtkWidget *widget,
 	return FALSE;
 }
 
-static GtkWidget *
-wrap_table_find_child_at_point (const EelWrapTable *wrap_table,
-			       int x,
-			       int y)
-{
-	GList *iterator;
-	
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), NULL);
-
-	for (iterator = wrap_table->details->children; iterator; iterator = iterator->next) {
-		GtkWidget *child;
-		
-		child = iterator->data;
-		
-		if (GTK_WIDGET_VISIBLE (child)) {
-			ArtIRect child_bounds;
-
-			child_bounds = eel_gtk_widget_get_bounds (child);
- 			
-			if (eel_art_irect_contains_point (child_bounds, x, y)) {
-				return child;
-			}
-		}
-	}
-
-	return NULL;
-}
-
 /**
  * eel_wrap_table_new:
  *
@@ -866,6 +810,7 @@ eel_wrap_table_get_y_spacing (const EelWrapTable *wrap_table)
 	return wrap_table->details->y_spacing;
 }
 
+
 /**
  * eel_wrap_table_find_child_at_event_point:
  * @wrap_table: A EelWrapTable.
@@ -876,18 +821,30 @@ eel_wrap_table_get_y_spacing (const EelWrapTable *wrap_table)
  */
 GtkWidget *
 eel_wrap_table_find_child_at_event_point (const EelWrapTable *wrap_table,
-					       int x,
-					       int y)
+					  int x,
+					  int y)
 {
-	EelArtIPoint scroll_offset;
-
-	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), NULL);
-
-	scroll_offset = wrap_table_get_scroll_offset (wrap_table);
+	GList *iterator;
 	
-	return wrap_table_find_child_at_point (wrap_table,
-					      x + ABS (scroll_offset.x),
-					      y + ABS (scroll_offset.y));
+  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), NULL);
+
+	for (iterator = wrap_table->details->children; iterator; iterator = iterator->next) {
+		GtkWidget *child;
+		
+		child = iterator->data;
+		
+		if (GTK_WIDGET_VISIBLE (child)) {
+			EelIRect child_bounds;
+
+			child_bounds = eel_gtk_widget_get_bounds (child);
+ 			
+			if (eel_irect_contains_point (child_bounds, x, y)) {
+				return child;
+			}
+		}
+	}
+
+	return NULL;
 }
 
 /**
